@@ -9,7 +9,7 @@ from xml.dom.minidom import Node
 from StringIO import StringIO
 
 from bigboard.stock import Stock
-from bigboard.slideout import ThemedSlideout
+from bigboard.slideout import Slideout
 import bigboard.google as google
 import bigboard.google_stock as google_stock  
 from bigboard.big_widgets import ActionLink, CanvasHBox, CanvasVBox, Button, Header, PrelightingCanvasBox, Arrow
@@ -86,15 +86,14 @@ class GoogleAccountInfo(AutoStruct):
         else: 
             return "Google Account: None Current folder: " + self.get_current_folder() + " Logged in: " + str(self.get_logged_in_flag()) + " Arrow state: " + self.get_expand_arrow().get_property("image_name")
 
-class LabelSlideout(ThemedSlideout):
+class LabelSlideout(Slideout):
     __gsignals__ = {
                     'changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING, )),
                    }
     def __init__(self, ga):
         super(LabelSlideout, self).__init__()
-        vbox = CanvasVBox(border_color=0x0000000ff, spacing=4)
-        self.get_root().append(vbox)
-        header = Header(topborder=False)
+        header = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL, classes="slideout-header")
+        self.get_root().append(header)
         if ga.domain and len(ga.domain) > 0:
             account_name = ga.name + "@" + ga.domain
         else:
@@ -102,7 +101,8 @@ class LabelSlideout(ThemedSlideout):
         account_text = ActionLink(text=account_name)
         account_text.connect("activated", on_visit_mail_account, account_name)
         header.append(account_text, hippo.PACK_EXPAND)        
-        vbox.append(header)
+        vbox = CanvasVBox(border_color=0x0000000ff, classes="slideout-main")
+        self.get_root().append(vbox)
         try:
             folderCounts = ga.getFolderCounts()
             folderCounts["unread"] = ga.getUnreadMsgCount()
@@ -126,19 +126,21 @@ class LabelSlideout(ThemedSlideout):
         self.emit('changed', label_text)
         self.emit('close', True)
 
-class EmailSlideout(ThemedSlideout):
+class EmailSlideout(Slideout):
     def __init__(self, thread):
         super(EmailSlideout, self).__init__()
-        vbox = CanvasVBox(border_color=0x0000000ff, spacing=4)
+        header = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL, classes="slideout-header")
+        self.get_root().append(header)
+
+        vbox = CanvasVBox(border_color=0x0000000ff, spacing=4, classes="slideout-main")
         self.get_root().append(vbox)
-        self.__header = Header(topborder=False)
+        
         self.id = thread.id        
 
         subject = gmail_jshtml_str_parse(thread.subject)
         
         subject_box = hippo.CanvasText(classes='header', text=subject)
-        self.__header.append(subject_box, hippo.PACK_EXPAND)
-        vbox.append(self.__header)
+        header.append(subject_box, hippo.PACK_EXPAND)
         
         for key in ("date", "categories", "snippet"):
             value = getattr(thread, key, None)
@@ -196,15 +198,14 @@ class MailStock(Stock, google_stock.GoogleStock):
     
     def update_google_data(self, gobj):
         # self.__current_gobj = gobj
-        # username = gobj.get_account().get_username()
-        # password = gobj.get_account().get_password()
-        # domain = gobj.get_account().get_url() 
+        # username = gobj.get_account().GetUsername()
+        # password = gobj.get_account().GetPassword()
         self.__update_email_box(gobj)
    
     def remove_google_data(self, gobj):
         if self.__google_accounts.has_key(gobj):
             self._box.remove(self.__google_accounts[gobj].get_google_account_box())
-            _logger.debug("will remove key for %s" % gobj.get_account().get_username())
+            _logger.debug("will remove key for %s" % gobj.get_account().GetUsername())
             del self.__google_accounts[gobj]
         
         # sometimes we don't even get the self.__google_accounts because the polling task didn't start, so 
@@ -220,11 +221,12 @@ class MailStock(Stock, google_stock.GoogleStock):
     @log_except(_logger)
     def __update_email_box (self, gobj):       
         _logger.debug("will update mailbox")
-        username = gobj.get_account().get_username()
-        password = gobj.get_account().get_password()
-        domain = gobj.get_account().get_url()
-        if domain and (len(domain) == 0 or domain == "gmail.com"):
+        (username, domain) = gobj.get_account().GetUsername().split('@', 1)
+        username = str(username)
+        domain = str(domain) 
+        if domain == "gmail.com":
             domain = None  
+        password = gobj.get_account().GetPassword()
 
         if not self.__google_accounts.has_key(gobj):
             self.__google_accounts[gobj] = GoogleAccountInfo()
@@ -247,7 +249,7 @@ class MailStock(Stock, google_stock.GoogleStock):
             # just calling the login() function again doesn't work
             if google_account is None or username != google_account.name or \
                password != google_account.password or domain != google_account.domain or self.__last_login_gobj != gobj:                 
-                _logger.debug("username %s domain %s password %s" % (username, domain, password))
+                _logger.debug("username %s domain %s password length %s" % (username, domain, len(password)))
                 google_account = libgmail.GmailAccount(username, password, domain = domain)
                 google_account.login()
             elif not logged_in_flag:
@@ -274,10 +276,10 @@ class MailStock(Stock, google_stock.GoogleStock):
             google_account_box.remove_all()
             account = CanvasHBox(xalign=hippo.ALIGNMENT_START)
  
-            account_name = ActionLink(text=gobj.get_account().get_username_as_google_email(), size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, font="14px")
-            account_name.connect("activated", on_visit_mail_account, gobj.get_account().get_username_as_google_email())
-            unread_message_count = ActionLink(text=" (%s)" % labelsDict['inbox'], font="14px", xalign=hippo.ALIGNMENT_START)
-            unread_message_count.connect("activated", on_visit_mail_account, gobj.get_account().get_username_as_google_email())
+            account_name = ActionLink(text=gobj.get_account().GetUsername(), size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
+            account_name.connect("activated", on_visit_mail_account, gobj.get_account().GetUsername())
+            unread_message_count = ActionLink(text=" (%s)" % labelsDict['inbox'], xalign=hippo.ALIGNMENT_START)
+            unread_message_count.connect("activated", on_visit_mail_account, gobj.get_account().GetUsername())
             # connecting to this signal once per GoogleAccountInfo did not work in all cases, and connecting multiple
             # times means that the function would be called multiple times, so we need to keep the expand_arrow_signal_id
             # to use it for disconnecting, and then connect again each time
@@ -298,8 +300,8 @@ class MailStock(Stock, google_stock.GoogleStock):
 
             label_and_arrow = CanvasHBox()
             label = CanvasHBox(xalign=hippo.ALIGNMENT_CENTER)
-            label_name = ActionLink(text=current_folder, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, font="12px Italic")
-            unread_message_count_for_label = ActionLink(text=" (%s)" % labelsDict[current_folder], font="12px Italic") 
+            label_name = ActionLink(text=current_folder, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, classes="action")
+            unread_message_count_for_label = ActionLink(text=" (%s)" % labelsDict[current_folder], classes="action") 
             arrow = Arrow(Arrow.RIGHT, arrow_size = 8, padding = 2)
              
             label.append(label_name)
@@ -317,7 +319,8 @@ class MailStock(Stock, google_stock.GoogleStock):
                 box = PrelightingCanvasBox()
                 box.connect("button-press-event", self.create_email_slideout, thread)
                 details_box.append(box)
-                email = hippo.CanvasText(markup=subject, xalign=hippo.ALIGNMENT_START)
+                email = hippo.CanvasText(markup=subject, xalign=hippo.ALIGNMENT_START,
+                                         size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
                 box.append(email)
                 i += 1
 
@@ -330,8 +333,9 @@ class MailStock(Stock, google_stock.GoogleStock):
         except libgmail.GmailLoginFailure:
             self._box.set_child_visible(self.__failed_to_connect_message, False) 
             google_account_box.remove_all()
-            account = ActionLink(text=gobj.get_account().get_username_as_google_email(), xalign=hippo.ALIGNMENT_START, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, font="14px")
-            account.connect("activated", on_visit_mail_account, gobj.get_account().get_username_as_google_email())
+
+            account = ActionLink(text=gobj.get_account().GetUsername(), xalign=hippo.ALIGNMENT_START, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
+            account.connect("activated", on_visit_mail_account, gobj.get_account().GetUsername())
             google_account_box.append(account)
             
             logged_in_flag = False
@@ -341,8 +345,9 @@ class MailStock(Stock, google_stock.GoogleStock):
         except urllib2.URLError:
             if not logged_in_flag:
                 google_account_box.remove_all()
-                account = ActionLink(text=gobj.get_account().get_username_as_google_email(), xalign=hippo.ALIGNMENT_START, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, font="14px")
-                account.connect("activated", on_visit_mail_account, gobj.get_account().get_username_as_google_email())
+
+                account = ActionLink(text=gobj.get_account().GetUsername(), xalign=hippo.ALIGNMENT_START, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
+                account.connect("activated", on_visit_mail_account, gobj.get_account().GetUsername())
                 google_account_box.append(account) 
  
             self._box.set_child_visible(self.__failed_to_connect_message, True) 
@@ -373,18 +378,21 @@ class MailStock(Stock, google_stock.GoogleStock):
         else:
             self._login_button.set_property('text', google_stock.LOGIN_TO_GOOGLE_STRING) 
             self._box.set_child_visible(self._login_button, True)
-        
+
     def show_slideout(self, widget):
         def on_slideout_close(s, action_taken):
             self.__last_slideout_event_time = gtk.get_current_event_time() 
             if action_taken:
                 self._panel.action_taken()
             s.destroy()
+            self._set_active(False)
+        self._set_active(True)
         self.__slideout.connect('close', on_slideout_close)
         y = widget.get_context().translate_to_screen(widget)[1]
         if not self.__slideout.slideout_from(204, y):
             self.__slideout.destroy()
             self.__slideout = None
+            self._set_active(False)
             return
     
     def create_label_slideout(self, widget, hippo_event, gobj):   
@@ -405,7 +413,7 @@ class MailStock(Stock, google_stock.GoogleStock):
         self.show_slideout(widget)
     
     def on_label_changed(self, slideout, label, gobj):
-        _logger.debug("will get new folder for %s" % gobj.get_account().get_username_as_google_email())
+        _logger.debug("will get new folder for %s" % gobj.get_account().GetUsername())
         self.__google_accounts[gobj].update({'current_folder' : label})
         self.__update_email_box(gobj)
     
@@ -432,7 +440,7 @@ class MailStock(Stock, google_stock.GoogleStock):
                 #  you must first close the existing Firefox process, or restart your system."
                 time.sleep(2)
                 done_with_sleep_state = 2  
-            libbig.show_url(create_account_url(google_account.get_account().get_username_as_google_email()))
+            libbig.show_url(create_account_url(google_account.get_account().GetUsername()))
             if done_with_sleep_state == 0:
                 done_with_sleep_state = 1
 
